@@ -15,24 +15,24 @@
 #  @author Marcello Stanisci
 
 from django.conf.urls import include, url
-from . import user
-from . import funds
+from django.views.generic.base import RedirectView
 from . import views
-from . import history
-from . import captcha
 
 urlpatterns = [
     url(r'^', include('talerbank.urls')),
-    url(r'^(?P<js>(use_js|no_js))?$', views.home_page, name='index'),
+    url(r'^$', RedirectView.as_view(pattern_name="profile"), name="index"),
     url(r'^favicon\.ico$', views.ignore),
-    url(r'^accounts/register/$', user.register_process, name="register"),
-    url(r'^accounts/login/$', views.home_page, name="login"),
-    url(r'^accounts/logout/$', user.logout_process, name="logout"),
+    url(r'^admin/add/incoming$', views.add_incoming, name="add-incoming"),
+    url(r'^javascript(?:.html)?/$', views.javascript_licensing, name="javascript"),
+    url(r'^login/$', views.login_view, name="login"),
+    url(r'^logout/$', views.logout_view, name="logout"),
+    url(r'^accounts/register/$', views.register, name="register"),
     url(r'^profile$', views.profile_page, name="profile"),
-    url(r'^withdraw$', funds.withdraw_nojs, name="withdraw-nojs"),
-    url(r'^public-accounts/details$', user.view_public_accno_process),
-    url(r'^public-accounts$', history.public_accounts_process, name="public-history"),
-    url(r'^pin/question$', captcha.pin_tan_question, name="pin_tan"),
-    url(r'^pin/verify$', captcha.pin_tan_verify),
+    url(r'^history$', views.history, name="history"),
+    url(r'^withdraw$', views.withdraw_nojs, name="withdraw-nojs"),
+    url(r'^public-accounts$', views.public_accounts, name="public-accounts"),
+    url(r'^public-accounts/(?P<name>[a-zA-Z0-9 ]+)$', views.public_accounts, name="public-accounts"),
+    url(r'^pin/question$', views.pin_tan_question, name="pin-question"),
+    url(r'^pin/verify$', views.pin_tan_verify, name="pin-verify"),
     url(r'^javascript$', views.javascript_licensing)
     ]
