@@ -99,6 +99,7 @@ def profile_page(request):
     context = dict(
         name=user_account.user.username,
         balance=amounts.stringify(amounts.floatify(user_account.balance_obj)),
+        sign = "-" if user_account.debit else "",
         currency=user_account.currency,
         precision=settings.TALER_DIGITS,
         account_no=user_account.account_no,
@@ -168,7 +169,7 @@ def pin_tan_question(request):
     request.session["exchange_url"] = request.GET["exchange"]
     request.session["reserve_pub"] = request.GET["reserve_pub"]
     request.session["sender_wiredetails"] = dict(
-        type="TEST",
+        type="test",
         bank_uri=request.build_absolute_uri(reverse("index")),
         account_number=user_account.account_no
     )
@@ -445,8 +446,9 @@ def auth_and_login(request):
 
     username = request.META.get("HTTP_X_TALER_BANK_USERNAME")
     password = request.META.get("HTTP_X_TALER_BANK_PASSWORD")
-    # logger.info("Trying to log '%s/%s' in" % (username, password))
+    logger.info("Trying to log '%s/%s' in" % (username, password))
     if not username or not password:
+        logger.error("user or password not given")
         return False
     return django.contrib.auth.authenticate(username=username,
                                             password=password)
@@ -473,6 +475,7 @@ def add_incoming(request):
     user_account = auth_and_login(request)
 
     if not user_account:
+        logger.error("authentication failed")
         return JsonResponse(dict(error="authentication failed"),
                             status=401)
 
@@ -491,6 +494,7 @@ def add_incoming(request):
     except SameAccountException:
         return JsonResponse(dict(error="debit and credit account are the same"), status=422)
     except DebtLimitExceededException:
+        logger.info("Prevenetd transfer, debit account would go beyond debt threshold")
         return JsonResponse(dict(error="debit count has reached its debt limit", status=403 ),
                              status=403)
     except amounts.CurrencyMismatchException as e:
@@ -506,11 +510,18 @@ def withdraw_nojs(request):
         logger.error("Amount did not pass parsing")
         return HttpResponseBadRequest()
 
+    user_account = BankAccount.objects.get(user=request.user)
+
     response = HttpResponse(status=202)
     response["X-Taler-Operation"] = "create-reserve"
     response["X-Taler-Callback-Url"] = reverse("pin-question")
-    response["X-Taler-Wt-Types"] = '["TEST"]'
+    response["X-Taler-Wt-Types"] = '["test"]'
     response["X-Taler-Amount"] = json.dumps(amount)
+    response["X-Taler-Sender-Wire"] = json.dumps(dict(
+        type="test",
+        bank_uri=request.build_absolute_uri(reverse("index")),
+        account_number=user_account.account_no
+    ))
     if settings.TALER_SUGGESTED_EXCHANGE:
         response["X-Taler-Suggested-Exchange"] = settings.TALER_SUGGESTED_EXCHANGE
     return response
@@ -585,7 +596,7 @@ def wire_transfer(amount,
         if 1 == amounts.amount_cmp(debit_account.balance_obj, threshold) \
            and 0 != amounts.amount_cmp(amounts.get_zero(), threshold) \
            and debit_account.debit:
-            logger.error("Negative balance '%s' not allowed." % json.dumps(debit_account.balance_obj))
+            logger.info("Negative balance '%s' not allowed." % json.dumps(debit_account.balance_obj))
             logger.info("%s's threshold is: '%s'." % (debit_account.user.username, json.dumps(threshold)))
             raise DebtLimitExceededException()
     except amounts.CurrencyMismatchException:
